---
title: PG 거래대사 가이드
category: 관리자콘솔 (관리자콘솔 사용 가이드) > PG 거래대사 > PG 거래대사
seo:
  title: PG 거래대사 가이드
  description: >-
    거래데이터와 정산데이터를 매핑하여 한 번에 정보를 확인하실 수 있는 포트원의 통합조회 서비스를 소개합니다. PG사와 간편결제사로부터
    정산받는 금액과 상세내역 등을 포트원 관리자콘솔에서 한 번에 조회 및 다운로드하실 수 있습니다.
  keywords:
    - PG 거래대사
    - 결제사 정산
    - 관리자콘솔
tags:
  - PG거래대사
pgCompanies:
  - KG이니시스
  - 나이스페이먼츠
  - NHN KCP
  - 토스페이먼츠
  - 헥토파이낸셜
  - 토스페이
  - 다날
  - 엑심베이
  - 페이코
  - 네이버페이(결제형)
  - 카카오페이
searchTags:
  - 건별 조회
  - 거래조회
  - 거래내역
  - PG정산
  - 결제사 정산
  - PG 거래대사
  - 거래대사
  - 정산데이터
  - 정산내역
  - 결제정산
  - 정산
---

## PG 거래대사

### **0.서비스 소개**

PG 거래대사 서비스에서는 포트원을 통해 연동된 아래 15개의 PG사 내역을 조회할 수 있습니다.

- KCP, KG이니시스, 나이스페이먼츠, 토스페이, 네이버페이, 다날, 페이코, UPLUS((구)토스페이먼츠), 토스페이먼츠, 카카오페이, 엑심베이, 헥토파이낸셜, KSNET, KPN, 하이픈

대사 서비스를 사용하기 위해 결제 연동 시 <Highlight text="임의 데이터가 아닌 실제 사용하는 주문번호로 연동" />이 필요합니다.\
정산 조회 동의를 한 이후부터 서비스를 이용하실 수 있습니다.\
네이버페이 정산 데이터를 확인하기 위해서는 정산 API 키 등록이 필요합니다.

- 정산 API 키 등록 방법\
  1\) [네이버페이센터](https://admin.pay.naver.com/) → 내정보 → 가입정보 변경 메뉴에서 정산 API 인증키 정보 확인\
  2\) [포트원 콘솔](https://admin.portone.io/auth/signin) → 결제 연동 → 연동 정보 → 네이버페이 선택 후 정산용 사이트 키(API Key) 입력



### 1. 기능 소개

#### 거래 대사

<Indent level="1">

- 포트원을 통해 연동된 고객사 주문 데이터와 PG사의 결제 정보를 자동 비교 / 대사하여 거래 이상 건수 및 금액을 쉽게 확인할 수 있습니다.
  - 거래일 기준으로 포트원 거래 데이터와 PG사 거래 데이터를 자동 대사합니다.
  - 다양한 PG사와 결제수단, 통화를 통합하여 일관된 기준으로 거래 및 정산 데이터를 제공합니다.

</Indent>

#### 정산 내역 확인

<Indent level="1">

- 정산금의 상세 내역을 확인할 수 있는 자료를 제공합니다.
  - 정산일 기준으로 정산 금액이 어떤 거래 데이터들로 이루어져 있는지 쉽게 확인할 수 있습니다.
  - 미래 정산금액 / 일자를 확인하여 현금 흐름 예측에 활용할 수 있습니다.

</Indent>

### 2. 메뉴별 기능 상세 설명

#### 거래 정산내역

포트원에 적재된 거래일 기준 고객사 거래데이터, 혹은 정산일 기준 정산데이터를 확인할 수 있습니다.

<Indent level="1">

- “거래내역”에서는 거래일 기준으로 데이터가 조회됩니다. PG 어드민 기준
- “정산내역”에서는 정산일 기준으로 데이터가 조회됩니다.

</Indent>

#### 거래 정산내역 서비스 설명

**포트원에 적재된 고객사 거래 데이터와 PG 거래 데이터를 비교하여 (거래 대사) 이상 거래 건에 대한 요약 정보를 확인할 때 용이합니다**



<Highlight text="① 요약대시보드  " />\
조회한 거래 결과의 요약을 확인할 수 있습니다.

- 조회기간, 상점 아이디, PG 고객 식별아이디의 필터가 결과값에 반영됩니다
- 총 거래건수와 총 거래금액 : 설정한 조건으로 조회한 총 거래 건수와 거래 금액을 확인할 수 있습니다.
- 총 거래 이상건수와 총 거래 이상 금액 : 설정한 조건으로 조회한 총 거래 이상 건수와 거래 이상 금액을 확인할 수 있습니다.
- 외화의 경우, 통화를 선택하여 통화별로 확인하실 수 있습니다.
  - 외화는 KRW(원화)로 환산하지 않으며 모든 통화에 대해서 지원합니다.
  - KRW로 환산하지 않기 때문에 거래일자가 같더라도 통화가 다를 경우 열을 구분하여 표시합니다.

<Highlight text="② 데이터 테이블" />

- 거래일 : PG 거래 데이터의 거래 일자를 기준으로 확인 가능하며, 동일한 거래 일자에 PG 고객 식별아이디로 하위 그룹핑된 데이터들을 함께 확인할 수 있습니다.



- 상위 & 하위 항목을 클릭할 경우 해당 일자의 모든 거래건 혹은, 개별 PG식별아이디에 대한 상세 내역을 \
  거래 건별 조회 메뉴로 이동하여 거래일 기준으로 상세 거래 내역 확인이 가능합니다.
- 대사상태 : 포트원에 연동된 고객사 주문 데이터와 PG사의 결제 정보를 대사한 상태값을 의미합니다.
- [계산 수식 정리내용 보러가기↗](https://help.portone.io/category/admin-console/pg-settlement?page=1#7_%EA%B0%81-%ED%85%8C%EC%9D%B4%EB%B8%94%EB%B3%84-%EA%B3%84%EC%82%B0-%EC%88%98%EC%8B%9D)

<Callout icon="💡" title="참고사항" content="대사상태 : **대사 일치, 대사 불일치, 대사 불능**
- 대사 상태에 관련해서 자세한 개념 설명 보러가기 ↗" />

- 상점 아이디 : 포트원을 사용하기 위해 설정한 상점을 구분하기 위한 값을 의미합니다.
- PG 고객 식별아이디 : PG 사에서 고객을 구분하기 위해 생성하는 고유한 값을 의미합니다.
- 거래건 수 : 해당 거래일자에 취소를 포함하여 발생한 총 거래건 수를 의미합니다.
- 거래 금액 : 해당 거래일자에 취소를 포함하여 발생한 총 거래 금액을 의미합니다.
- 취소건 수 : 해당 거래일자에 발생한 총 취소건 수를 의미합니다.
- 취소 금액 : 해당 거래일자에 발생한 총 취소 금액을 의미합니다.
- 거래 이상 건수 : 해당 거래일자에 발생한 총 거래 이상 건수를 의미합니다.
- 거래 이상 금액 : 해당 거래일자에 발생한 총 거래 이상 금액을 의미합니다.

<Highlight text="※ 거래 이상 : 대사불일치, 대사불능인 거래를 의미합니다." />

<Highlight text="③ 조회 기간 설정" />: 조회하고 싶은 기간을 설정해서 데이터 확인이 가능합니다.

- 원하는 기간을 자유롭게 설정할 수 있고, 과거 데이터는 최대 3개월까지 조회가 가능합니다.

<Highlight text="④ 표 설정" /> : 표에서 확인할 항목을 커스터마이징 할 수 있습니다.



- 선택 가능한 설정 값 : 거래일, 대사상태, 상점아이디, PG 고객 식별아이디, 거래건 수, 거래 금액, 취소건 수, 취소 금액, 거래 이상 건수, 거래 이상 금액

<Highlight text="⑤ 엑셀 다운로드" />: 조회 조건에 해당하는 전체 데이터를 엑셀로 다운로드할 수 있습니다.

#### 거래 건별조회  서비스 설명

포트원에 적재된 고객사 거래정산데이터 상세내역을 확인할 수 있으며\
1\) 거래 대사 이후 각 이상 거래 건에 대한 자세한 정보 확인이 필요하거나\
2\) 일정 기간 동안 정산 받은 금액이 어떤 거래 건으로 이루어져있는지 확인이 필요한 경우에 \
유용하게 사용 가능합니다.



<Highlight text="①검색" />: 검색하고자 하는 내용과 정확히 일치하는 입력값을 입력해야 검색이 가능합니다.

- 검색 가능 조건
  - 주문명
  - PG 거래 번호
  - 고객사 거래 번호
  - 포트원 거래 번호

<Highlight text="② 조회 기준일" /> : 거래일/정산일을 선택할 수 있습니다.

<Highlight text="③ 데이터 테이블" />

- 확인 가능한 데이터 : 대사상태 / 거래구분 / 거래일 / 정산일 / 상점 아이디 / PG 고객 식별아이디 / 고객사 주문번호 / PG 결제번호 / 포트원 결제번호 / 거래유형 / 거래 금액 / 공급가액 / 면세가액 / 부가세 / PG 수수료 / PG 수수료 부가세 / 정산 금액 / 거래 이상 금액 / 에스크로
- 대사상태 : 대사일치 / 대사불일치 / 대사불능 / 수집전거래
- 거래구분 : 승인 / 취소 / 부분취소 / 기타취소

<Highlight text="※ 기타 취소 : 전체 취소인지 부분취소인지 식별할 수 없는 취소 건 (unclassified cancel)" />

- 거래유형 : 카드 / 간편결제 / 간편결제 충전 / 계좌이체 / 가상계좌 / 모바일 / 상품권 / ARS / 기타

<Highlight text="※ 거래 유형에 따라 표시되는 상세 정보 확인이 필요하다면? " />

### 3. 부연 설명

<Callout icon="💡" content="각 칼럼에 표시되는 데이터의 수식을 확인하실 수 있습니다." title="참고사항" />

#### 거래 유형 상세 정보

##### 거래 유형에 마우스오버시 카드 형태로 상세 정보가 보여집니다.

<Indent level="1">

- 카드  :  발급사, 매입사, 카드 승인번호, 카드 할부개월수
- 상품권 : 타입, 승인번호
- 계좌이체 : 은행이름, 승인번호
- 가상계좌 : 은행이름, 승인번호
- 간편결제 : 간편결제사 이름
- 모바일 결제 : 통신사
- 기타 : 기타

</Indent>

#### 대사 상태값 정리

<Indent level="1">

- 대사 일치 : 대사하였을 때 PG 거래 데이터와 고객사 거래 데이터의 차이가 없이 일치하는 경우를 의미합니다.
- 대사 불능 : 대사하였을 때 PG사나 고객사 중 어느 한 쪽의 데이터가 없어서 비교할 수 없는 경우를 의미합니다.
- 수집전거래 : 오래된 거래 건이 늦게 정산되어, PG사에서 수집 가능한 거래정보가 없는 경우를 의미합니다.
  (PG 거래 데이터 ↔ PG 정산 데이터 비교 후 거래 데이터가 누락되어 있는 경우)
- 대사 불일치 : 대사 불일치의 경우는 아래와 같이 정리할 수 있습니다.

</Indent>

<Indent level="2">

<대사 불일치 상태값 사유 및 설명>

- 결제 금액 불일치 : 두 원장의 결제 금액이 불일치합니다.\
  (금액 차이가 있으면 무조건 불일치로 표시)
- 면세 금액 불일치 :  두 원장의 면세금액이 불일치합니다. \
  (금액 차이가 있으면 무조건 불일치로 표시)
- 부가세 금액 불일치 : 두 원장의 부가세 금액이 불일치합니다. \
  (금액 차이가 있으면 무조건 불일치로 표시)
- 에스크로 여부 불일치 : 두 원장에서 에스크로(안전결제)여부가 불일치합니다. (Y/N 다르면 불일치 표시)
- 할부 개월 수 불일치 : 두 원장의 카드 할부개월 수가 불일치합니다. \
  (할부개월수 다르면 불일치 표시)
- 결제일자 불일치 :두 원장의 결제일시가 불일치합니다. 시스템으로 인해 차이날 수 있는 근소한 차이의 경우는 일치로 처리합니다. \
  (두 원장의 결제일시가 다른 일자에 일어나면 불일치 표시)\
  (자정 기점으로 PG<>포트원 전송시간에 의해 거래일자가 변경되는 경우도 다른 일자일 경우 불일치 표시)

</Indent>

#### 각 테이블별 계산 수식

<Indent level="1">

- 거래 건수 : 조회기간 내 (승인) 건수
- 거래 금액 : 조회기간 내 (승인) 금액
- 취소 건수 : 조회기간내 (취소) + (부분취소) + (기타취소) 건수
- 취소 금액 : 조회기간 내 (취소 금액) + (부분취소) + (기타취소) 금액
- 정산건수 : 조회기간 내 거래건수 - 취소건수 + 기타정산건(수집이전거래건수; 승인과 취소, 부분 취소 데이터가 없는 정산 데이터)
- 정산금액 : 조회기간 내 거래금액 - 취소금액 - PG 수수료 - PG 수수료 VAT
- 공급가액 : 거래 금액 - 할인 금액 - 면세가액 - 부가세 \
  (과세사업자 면세가액=0)
- 부가세 :  (거래 금액-면세가액)/11 후 반올림
  (과세사업자 면세가액=0)
- 거래 이상금액 : 거래불일치 금액 절대값 + 거래대사 불능금액
- PG 수수료 부가세 : PG사에서 값을 주지 않을 경우 PG수수료/10 후 반올림

</Indent>

<Callout icon="💡" title="FAQ" content="1. 과거 데이터 조회 기준은 ?
→ 최대 3개월까지 가능합니다.

2. 실시간 데이터 업데이트가 가능한가요? 아니면 일별 업데이트인가요?
→ PG 사 마감 데이터를 가져와야 하므로 전날 기준 거래, 정산데이터를 가져와서 일별 업데이트를 진행하고 있습니다.

3. 복합 결제(예: 신용카드+포인트)의 경우, 데이터 처리는 어떻게 이루어지나요?
→ 별도로 구분되지 않고 간편결제로 표시됩니다.

4. 환불, 부분 취소 등의 예외 케이스는 어떻게 처리되나요?
→ 거래 상태값에 부분취소, 취소로 처리되고 있습니다." />
